==> react-molecule-input-field-3.4.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomInput, { inputStates } from '@s-ui/react-atom-input';

var getErrorState = function getErrorState(_ref) {
  var successText = _ref.successText,
      errorText = _ref.errorText;
  if (successText) return false;
  if (errorText) return true;
};

var getState = function getState(_ref2) {
  var successText = _ref2.successText,
      errorState = _ref2.errorState,
      alertText = _ref2.alertText;
  if (successText) return inputStates.SUCCESS;
  if (errorState) return inputStates.ERROR;
  if (alertText) return inputStates.ALERT;
};

var MoleculeInputField = function MoleculeInputField(_ref3) {
  var id = _ref3.id,
      label = _ref3.label,
      successText = _ref3.successText,
      errorText = _ref3.errorText,
      alertText = _ref3.alertText,
      helpText = _ref3.helpText,
      _ref3$autoHideHelpTex = _ref3.autoHideHelpText,
      autoHideHelpText = _ref3$autoHideHelpTex === void 0 ? false : _ref3$autoHideHelpTex,
      inline = _ref3.inline,
      onChange = _ref3.onChange,
      useContrastLabel = _ref3.useContrastLabel,
      props = _objectWithoutPropertiesLoose(_ref3, ["id", "label", "successText", "errorText", "alertText", "helpText", "autoHideHelpText", "inline", "onChange", "useContrastLabel"]);

  var errorState = getErrorState({
    successText: successText,
    errorText: errorText
  });
  var inputState = getState({
    successText: successText,
    errorState: errorState,
    alertText: alertText
  });
  return React.createElement(MoleculeField, {
    name: id,
    label: label,
    successText: successText,
    errorText: errorText,
    alertText: alertText,
    helpText: helpText,
    autoHideHelpText: autoHideHelpText,
    inline: inline,
    onChange: onChange,
    useContrastLabel: useContrastLabel
  }, React.createElement(AtomInput, Object.assign({
    id: id,
    errorState: errorState,
    state: inputState
  }, props)));
};

MoleculeInputField.displayName = 'MoleculeInputField';
export default MoleculeInputField;

==> react-molecule-input-field-3.5.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import AtomInput, { inputStates } from '@s-ui/react-atom-input';

var getErrorState = function getErrorState(_ref) {
  var successText = _ref.successText,
      errorText = _ref.errorText;
  if (successText) return false;
  if (errorText) return true;
};

var getState = function getState(_ref2) {
  var successText = _ref2.successText,
      errorState = _ref2.errorState,
      alertText = _ref2.alertText;
  if (successText) return inputStates.SUCCESS;
  if (errorState) return inputStates.ERROR;
  if (alertText) return inputStates.ALERT;
};

var MoleculeInputField = function MoleculeInputField(_ref3) {
  var id = _ref3.id,
      label = _ref3.label,
      successText = _ref3.successText,
      errorText = _ref3.errorText,
      alertText = _ref3.alertText,
      helpText = _ref3.helpText,
      _ref3$autoHideHelpTex = _ref3.autoHideHelpText,
      autoHideHelpText = _ref3$autoHideHelpTex === void 0 ? false : _ref3$autoHideHelpTex,
      inline = _ref3.inline,
      onChange = _ref3.onChange,
      useContrastLabel = _ref3.useContrastLabel,
      props = _objectWithoutPropertiesLoose(_ref3, ["id", "label", "successText", "errorText", "alertText", "helpText", "autoHideHelpText", "inline", "onChange", "useContrastLabel"]);

  var errorState = getErrorState({
    successText: successText,
    errorText: errorText
  });
  var inputState = getState({
    successText: successText,
    errorState: errorState,
    alertText: alertText
  });
  return /*#__PURE__*/React.createElement(MoleculeField, {
    name: id,
    label: label,
    successText: successText,
    errorText: errorText,
    alertText: alertText,
    helpText: helpText,
    autoHideHelpText: autoHideHelpText,
    inline: inline,
    onChange: onChange,
    useContrastLabel: useContrastLabel
  }, /*#__PURE__*/React.createElement(AtomInput, Object.assign({
    id: id,
    errorState: errorState,
    state: inputState
  }, props)));
};

MoleculeInputField.displayName = 'MoleculeInputField';
export default MoleculeInputField;
